.. _api-utils:

.. currentmodule:: cratermaker.utils

Utility functions
=================

.. _api-utils-montecarlo:

Monte Carlo
-----------

.. autosummary::
   :toctree: generated/

    montecarlo_utils.get_random_location
    montecarlo_utils.get_random_impact_angle
    montecarlo_utils.get_random_velocity
    montecarlo_utils.get_random_size
    montecarlo_utils.bounded_norm

.. _api-utils-general:

General utilities
-----------------

.. autosummary::
    :toctree: generated/

    general_utils.Parameter
    general_utils.normalize_coords
    general_utils.validate_and_normalize_location
    general_utils.R_to_CSFD
    general_utils.format_large_units


